@@ -12,14 +12,15 @@
 ;;;; 
 ;;;; You should have received a copy of the GNU General Public License
 ;;;; along with this software; see the file COPYING.  If not, write to
-;;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;;;; the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+;;;; Boston, MA 02111-1307 USA
 ;;;;
 ;;;; The author can be reached at djurfeldt@nada.kth.se
 ;;;; Mikael Djurfeldt, SANS/NADA KTH, 10044 STOCKHOLM, SWEDEN
 ;;;;
 
 
-(define-module #/ice-9/debug)
+(define-module (ice-9 debug))
 
 
 
