@@ -1,5 +1,5 @@
 ;;; installed-scm-file
-(define-module #/ice-9/slib)
+(define-module (ice-9 slib))
   
 
 
@@ -19,6 +19,7 @@
 
 (define slib:exit quit)
 (define slib:error error)
+(define slib:warn warn)
 (define slib:eval eval)
 (define defmacro:eval eval)
 (define logical:logand logand)
@@ -107,19 +108,29 @@
 		'()))))
 
 
+;;; FIXME: Because uers want require to search the path, this uses
+;;; primitive-load-path, which probably isn't a hot idea.  slib
+;;; doesn't expect this function to search a path, so I expect to get
+;;; bug reports at some point complaining that the wrong file gets
+;;; loaded when something accidentally appears in the path before
+;;; slib, etc. ad nauseum.  However, the right fix seems to involve
+;;; changing catalog:get in slib/require.scm, and I don't expect
+;;; Aubrey will integrate such a change.  So I'm just going to punt
+;;; for the time being.
 (define (slib:load name)
   (save-module-excursion
    (lambda ()
      (set-current-module slib-module)
      (let* ((errinfo (catch 'system-error
 			    (lambda ()
-			      (basic-load name)
+			      (primitive-load-path name)
 			      #f)
 			    (lambda args args)))
 	    (errinfo (and errinfo
 			  (catch 'system-error
 				 (lambda ()
-				   (basic-load (string-append name ".scm"))
+				   (primitive-load-path
+				    (string-append name ".scm"))
 				   #f)
 				 (lambda args args)))))
        (if errinfo
@@ -144,6 +155,8 @@
 (define (output-port-width . arg) 80)
 (define (output-port-height . arg) 24)
 
+(define (identity x) x)
+
 ;;; {Time}
 ;;;
 
