@@ -14,7 +14,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -38,8 +39,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 /* "dynl.c" dynamically link&load object files.
    Author: Aubrey Jaffer
@@ -60,7 +60,10 @@ sysdep_dynl_link (fname, subr)
 {
     void *handle = dlopen (fname, DLOPEN_MODE);
     if (NULL == handle)
+      {
+	SCM_ALLOW_INTS;
 	scm_misc_error (subr, (char *)dlerror (), SCM_EOL);
+      }
     return handle;
 }
 
@@ -69,13 +72,11 @@ sysdep_dynl_unlink (handle, subr)
      void *handle;
      char *subr;
 {
-    int status;
-
-    SCM_DEFER_INTS;
-    status = dlclose (handle);
-    SCM_ALLOW_INTS;
-    if(status)
+    if (dlclose (handle))
+      {
+	SCM_ALLOW_INTS;
 	scm_misc_error (subr, (char *)dlerror (), SCM_EOL);
+      }
 }
    
 static void *
@@ -87,13 +88,13 @@ sysdep_dynl_func (symb, handle, subr)
     void *fptr;
     char *err;
 
-    SCM_DEFER_INTS;
     fptr = dlsym (handle, symb);
     err = (char *)dlerror ();
-    SCM_ALLOW_INTS;
-
     if (!fptr)
+      {
+	SCM_ALLOW_INTS;
 	scm_misc_error (subr, err? err : "symbol has NULL address", SCM_EOL);
+      }
     return fptr;
 }
 
