@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 /* Guile high level (gh_) interface, initialization-related stuff */
@@ -69,7 +69,7 @@ gh_launch_pad (void *closure, int argc, char **argv)
 void 
 gh_enter (int argc, char *argv[], main_prog_t c_main_prog)
 {
-  scm_boot_guile (argc, argv, gh_launch_pad, c_main_prog);
+  scm_boot_guile (argc, argv, gh_launch_pad, (void *) c_main_prog);
   /* never returns */
 }
 
