@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include <stdio.h>
@@ -81,6 +81,9 @@
 #include "pairs.h"
 #include "ports.h"
 #include "posix.h"
+#ifdef HAVE_REGCOMP
+#include "regex-posix.h"
+#endif
 #include "print.h"
 #include "procprop.h"
 #include "procs.h"
@@ -415,6 +418,9 @@ scm_boot_guile_1 (base, closure)
       scm_init_pairs ();
       scm_init_ports ();
       scm_init_posix ();
+#ifdef HAVE_REGCOMP
+      scm_init_regex_posix ();
+#endif
       scm_init_procs ();
       scm_init_procprop ();
       scm_init_scmsigs ();
@@ -467,8 +473,6 @@ scm_boot_guile_1 (base, closure)
   setjmp_val = setjmp (SCM_JMPBUF (scm_rootcont));
   if (!setjmp_val)
     {
-      scm_init_signals ();
-
       scm_set_program_arguments (closure->argc, closure->argv, 0);
       scm_internal_catch (SCM_BOOL_T, invoke_main_func, closure,
 			  scm_handle_by_message, 0);
