@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include <stdio.h>
@@ -47,6 +47,7 @@
 #include "read.h"
 #include "eval.h"
 #include "throw.h"
+#include "alist.h"
 
 #include "load.h"
 
@@ -129,9 +130,10 @@ scm_init_load_path ()
   SCM path = SCM_EOL;
 
 #ifdef SCM_LIBRARY_DIR
-  path = scm_cons2 (scm_makfrom0str (SCM_SITE_DIR),
-		    scm_makfrom0str (SCM_LIBRARY_DIR),
-		    path);
+  path = scm_listify (scm_makfrom0str (SCM_SITE_DIR),
+		      scm_makfrom0str (SCM_LIBRARY_DIR),
+		      scm_makfrom0str (SCM_PKGDATA_DIR),
+		      SCM_UNDEFINED);
 #endif /* SCM_LIBRARY_DIR */
   
   {
@@ -321,7 +323,25 @@ scm_read_and_eval_x (port)
 }
 
 
+/* Information about the build environment.  */
 
+/* Initialize the scheme variable %guile-build-info, based on data
+   provided by the Makefile, via libpath.h.  */
+static void
+init_build_info ()
+{
+  static struct { char *name; char *value; } info[] = SCM_BUILD_INFO;
+  SCM *loc = SCM_CDRLOC (scm_sysintern ("%guile-build-info", SCM_EOL));
+  int i;
+
+  for (i = 0; i < (sizeof (info) / sizeof (info[0])); i++)
+    *loc = scm_acons (SCM_CAR (scm_intern0 (info[i].name)),
+		      scm_makfrom0str (info[i].value),
+		      *loc);
+}
+
+
+
 void
 scm_init_load ()
 {
@@ -333,5 +353,7 @@ scm_init_load ()
 					    SCM_UNDEFINED)));
   scm_loc_load_hook = SCM_CDRLOC(scm_sysintern("%load-hook", SCM_BOOL_F));
 
+  init_build_info ();
+
 #include "load.x"
 }
