@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 #include <stdio.h>
 #include "_scm.h"
@@ -49,6 +49,7 @@
 #include "fports.h"
 #include "strports.h"
 #include "vports.h"
+#include "kw.h"
 
 #include "ports.h"
 
@@ -456,6 +457,23 @@ scm_force_output (port)
   }
 }
 
+SCM_PROC (s_flush_all_ports, "flush-all-ports", 0, 1, 0, scm_flush_all_ports);
+SCM
+scm_flush_all_ports (void)
+{
+  int i;
+
+  for (i = 0; i < scm_port_table_size; i++)
+    {
+      SCM port = scm_port_table[i]->port;
+      if (SCM_OPOUTPORTP (port))
+	{
+	  scm_sizet ptob = SCM_PTOBNUM (port);
+	  (scm_ptobs[ptob].fflush) (SCM_STREAM (port));
+	}
+    }
+  return SCM_UNSPECIFIED;
+}
 
 SCM_PROC(s_read_char, "read-char", 0, 1, 0, scm_read_char);
 
@@ -693,37 +711,26 @@ scm_ports_prehistory ()
 int scm_tc16_void_port = 0;
 
 static int
-print_void_port (exp, port, writing)
-     SCM exp;
-     SCM port;
-     int writing;
+print_void_port (SCM exp, SCM port, scm_print_state *pstate)
 {
   scm_prinport (exp, port, "void");
   return 1;
 }
 
 static int
-putc_void_port (c, strm)
-     int c;
-     SCM strm;
+putc_void_port (int c, SCM strm)
 {
   return 0;			/* vestigial return value */
 }
 
 static int
-puts_void_port (s, strm)
-     char * s;
-     SCM strm;
+puts_void_port (char *s, SCM strm)
 {
   return 0;			/* vestigial return value */
 }
 
 static scm_sizet
-write_void_port (ptr, size, nitems, strm)
-     void * ptr;
-     int size;
-     int nitems;
-     SCM strm;
+write_void_port (char *ptr, scm_sizet size, scm_sizet nitems, SCM strm)
 {
   int len;
   len = size * nitems;
@@ -731,42 +738,30 @@ write_void_port (ptr, size, nitems, strm)
 }
 
 
-static int flush_void_port SCM_P ((SCM strm));
-
 static int
-flush_void_port (strm)
-     SCM strm;
+flush_void_port (SCM strm)
 {
   return 0;
 }
 
 
-static int getc_void_port SCM_P ((SCM strm));
-
 static int
-getc_void_port (strm)
-     SCM strm;
+getc_void_port (SCM strm)
 {
   return EOF;
 }
 
 
-static int close_void_port SCM_P ((SCM strm));
-
 static int
-close_void_port (strm)
-     SCM strm;
+close_void_port (SCM strm)
 {
   return 0;			/* this is ignored by scm_close_port. */
 }
 
 
 
-static int noop0 SCM_P ((SCM stream));
-
 static int 
-noop0 (stream)
-     SCM stream;
+noop0 (SCM stream)
 {
   return 0;
 }
