@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include "extchrs.h"
@@ -399,6 +399,13 @@ tryagain_no_flush_ws:
 	      return SCM_MAKICHR (scm_charnums[c]);
 	  scm_wta (SCM_UNDEFINED, "unknown # object: #\\", SCM_CHARS (*tok_buf));
 
+	  /* #:SYMBOL is a syntax for keywords supported in all contexts.  */
+	case ':':
+	  j = scm_read_token ('-', tok_buf, port, 0);
+	  p = scm_intern (SCM_CHARS (*tok_buf), j);
+	  if (SCM_PORT_REPRESENTATION (port) != scm_regular_port)
+	    scm_set_symbol_multi_byte_x (SCM_CAR (p), SCM_BOOL_T);
+	  return scm_make_keyword_from_dash_symbol (SCM_CAR (p));
 
 	default:
 	callshrp:
