@@ -2,7 +2,7 @@
 
 #ifndef SCMSIGSH
 #define SCMSIGSH
-/*	Copyright (C) 1995,1996 Free Software Foundation, Inc.
+/*	Copyright (C) 1995,1996,1997 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -40,21 +41,18 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 #include "libguile/__scm.h"
 
 
 
+extern SCM scm_sigaction (SCM signum, SCM handler, SCM flags);
+extern SCM scm_restore_signals SCM_P ((void));
 extern SCM scm_alarm SCM_P ((SCM i));
 extern SCM scm_pause SCM_P ((void));
 extern SCM scm_sleep SCM_P ((SCM i));
 extern SCM scm_raise SCM_P ((SCM sig));
-extern void scm_init_signals SCM_P ((void));
-extern void scm_ignore_signals SCM_P ((void));
-extern void scm_unignore_signals SCM_P ((void));
-extern SCM scm_restore_signals SCM_P ((void));
 extern void scm_init_scmsigs SCM_P ((void));
 
 #endif  /* SCMSIGSH */
