@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include <stdio.h>
@@ -67,13 +67,11 @@ scm_system(cmd)
   SCM_ASSERT(SCM_NIMP(cmd) && SCM_ROSTRINGP(cmd), cmd, SCM_ARG1, s_system);
   if (SCM_ROSTRINGP (cmd))
     cmd = scm_makfromstr (SCM_ROCHARS (cmd), SCM_ROLENGTH (cmd), 0);
-  scm_ignore_signals();
 # ifdef AZTEC_C
   cmd = SCM_MAKINUM(Execute(SCM_ROCHARS(cmd), 0, 0));
 # else
   cmd = SCM_MAKINUM(0L+system(SCM_ROCHARS(cmd)));
 # endif
-  scm_unignore_signals();
   return cmd;
 }
 #endif
