@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,8 +37,7 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include <stdio.h>
@@ -116,7 +116,7 @@ scm_string (chrs)
 	  int l;
 	  char * c;
 	  l = SCM_ROLENGTH (SCM_CAR (chrs));
-	  c = SCM_ROUCHARS (SCM_CAR (chrs));
+	  c = SCM_ROCHARS (SCM_CAR (chrs));
 	  while (l)
 	    {
 	      --l;
