@@ -12,7 +12,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -36,13 +37,14 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include <stdio.h>
 #include "_scm.h"
 #include "chars.h"
+#include "genio.h"
+#include "eval.h"
 
 #include "struct.h"
 
@@ -54,6 +56,7 @@
 
 static SCM required_vtable_fields = SCM_BOOL_F;
 static int struct_num = 0;
+static SCM struct_printer_var;
 
 
 SCM_PROC (s_struct_make_layout, "make-struct-layout", 1, 0, 0, scm_make_struct_layout);
@@ -195,7 +198,7 @@ init_struct (handle, tail_elts, inits)
 
 	case 'p':
 	  if ((prot != 'r' && prot != 'w') || inits == SCM_EOL)
-	    *mem = SCM_EOL;
+	    *mem = SCM_BOOL_F;
 	  else
 	    {
 	      *mem = SCM_CAR (inits);
@@ -434,7 +437,7 @@ scm_struct_ref (handle, pos)
   p = SCM_INUM (pos);
 
   fields_desc = (unsigned char *)SCM_CHARS (layout);
-  n_fields = data[- scm_struct_n_extra_words] - scm_struct_n_extra_words;
+  n_fields = data[scm_struct_i_n_words] - scm_struct_n_extra_words;
   
   SCM_ASSERT (p < n_fields, pos, SCM_OUTOFRANGE, s_struct_ref);
 
@@ -516,7 +519,7 @@ scm_struct_set_x (handle, pos, val)
   p = SCM_INUM (pos);
 
   fields_desc = (unsigned char *)SCM_CHARS (layout);
-  n_fields = data[- scm_struct_n_extra_words] - scm_struct_n_extra_words;
+  n_fields = data[scm_struct_i_n_words] - scm_struct_n_extra_words;
 
   SCM_ASSERT (p < n_fields, pos, SCM_OUTOFRANGE, s_struct_set_x);
 
@@ -595,6 +598,22 @@ scm_struct_vtable_tag (handle)
 
 
 
+void
+scm_print_struct (exp, port, pstate)
+     SCM exp;
+     SCM port;
+     scm_print_state *pstate;
+{
+  SCM prt = SCM_CDR (struct_printer_var);
+  if (SCM_FALSEP(prt) ||
+      SCM_FALSEP(scm_apply (prt, exp, scm_cons (port, scm_listofnull))))
+    {
+      scm_gen_write (scm_regular_string, "#<struct ", sizeof ("#<struct ") - 1,
+		     port);
+      scm_intprint (exp, 16, port);
+      scm_gen_putc ('>', port);
+    }
+}
 
 void
 scm_init_struct ()
@@ -602,6 +621,7 @@ scm_init_struct ()
   required_vtable_fields = SCM_CAR (scm_intern_obarray ("pruosr", sizeof ("pruosr") - 1, SCM_BOOL_F));
   scm_permanent_object (required_vtable_fields);
   scm_sysintern ("struct-vtable-offset", SCM_MAKINUM (scm_struct_i_vtable_offset));
+  struct_printer_var = scm_sysintern("*struct-printer*", SCM_BOOL_F);
 #include "struct.x"
 }
 
