@@ -16,7 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307 USA
  *
  * As a special exception, the Free Software Foundation gives permission
  * for additional uses of the text contained in its release of GUILE.
@@ -40,11 +41,11 @@
  *
  * If you write modifications of your own for GUILE, it is your choice
  * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.  
- */
+ * If you do not wish that, delete this exception notice.  */
 
 
 #include "libguile/__scm.h"
+#include "libguile/print.h"
 
 
 
@@ -81,6 +82,7 @@ extern SCM scm_struct_ref SCM_P ((SCM handle, SCM pos));
 extern SCM scm_struct_set_x SCM_P ((SCM handle, SCM pos, SCM val));
 extern SCM scm_struct_vtable SCM_P ((SCM handle));
 extern SCM scm_struct_vtable_tag SCM_P ((SCM handle));
+extern void scm_print_struct SCM_P ((SCM exp, SCM port, scm_print_state *));
 extern void scm_init_struct SCM_P ((void));
 
 #endif  /* STRUCTH */
